import type { ReactElement, ReactNode } from 'react';
import DataLoader from './dataloader';
import type { OnErrorFn, PromiseType } from './types';
type CachedData = Record<string, unknown>;
type Reloads = Record<string, () => Promise<void | unknown>>;
type UseDataLoaderInitializerArgs<ResultType = unknown> = {
    method: () => PromiseType<ResultType>;
    enabled?: boolean;
};
type GetCachedDataFn = {
    (): CachedData;
    (key?: string): unknown | undefined;
};
type GetReloadsFn = {
    (): Reloads;
    (key?: string): (() => Promise<void | unknown>) | undefined;
};
export type IDataLoaderContext = {
    addRequest: <ResultType, ErrorType>(key: string, args: UseDataLoaderInitializerArgs<ResultType>) => DataLoader<ResultType, ErrorType>;
    getOrAddRequest: <ResultType, ErrorType>(key: string, args: UseDataLoaderInitializerArgs<ResultType>) => DataLoader<ResultType, ErrorType>;
    computeKey: (key: string) => string;
    cacheKeyPrefix?: string;
    defaultDatalifetime?: number;
    onError?: (error: Error) => void | Promise<void>;
    clearAllCachedData: () => void;
    clearCachedData: (key: string) => void;
    getCachedData: GetCachedDataFn;
    getReloads: GetReloadsFn;
    getRequest: <ResultType, ErrorType>(key: string) => DataLoader<ResultType, ErrorType>;
    reload: (key?: string) => Promise<void>;
    reloadAll: () => Promise<void>;
    reloadGroup: (startKey?: string) => Promise<void>;
};
export declare const DataLoaderContext: import("react").Context<IDataLoaderContext>;
type DataLoaderProviderProps = {
    children: ReactNode;
    cacheKeyPrefix?: string;
    onError?: OnErrorFn;
    maxConcurrentRequests?: number;
    /**
     * Default request lifetime in milliseconds. It doesnt override values passed to hooks
     */
    defaultDatalifetime?: number;
};
declare const DataLoaderProvider: ({ children, cacheKeyPrefix, onError, maxConcurrentRequests, defaultDatalifetime, }: DataLoaderProviderProps) => ReactElement;
export declare const useDataLoaderContext: () => IDataLoaderContext;
export default DataLoaderProvider;
